Installation
============

Binary installers for the latest released version are available at the Python Package Index (`PyPI <https://pypi.org/>`_):

.. code-block:: shell

    pip install pydwca

This will install the library and the dependencies listed on `requirements <https://github.com/IEB-BIODATA/pydwca/blob/main/requirements.txt>`_. This will give you a basic usage.

If you want all the available features install the optional dependencies:

.. code-block:: shell

    pip install pydwca[full]
    pip install pydwca[ui]
    pip install pydwca[data]

`full` has all features, `ui` allow to see the steps of the long process and `data` includes the libraries for data analysis.
